@@ -13,7 +13,7 @@ BEGIN {
     __PACKAGE__->mk_accessors(qw/_config realm/);
 }
 
-our $VERSION = "1.006";
+our $VERSION = "1.007";
 
 sub new {
     my ($class, $config, $app, $realm) = @_;
@@ -60,8 +60,11 @@ sub authenticate_basic {
 
     if ( my ( $username, $password ) = $headers->authorization_basic ) {
 	    my $user_obj = $realm->find_user( { $self->_config->{username_field} => $username }, $c);
-	    if (ref($user_obj)) {            
-            if ($self->check_password($user_obj, {$self->_config->{password_field} => $password})) {
+	    if (ref($user_obj)) {
+            my $opts = {};
+            $opts->{$self->_config->{password_field}} = $password 
+                if $self->_config->{password_field};            
+            if ($self->check_password($user_obj, $opts)) {
                 $c->set_authenticated($user_obj);
                 return $user_obj;
             }
@@ -98,7 +101,7 @@ sub authenticate_digest {
         $c->log->debug('Checking authentication parameters.')
           if $c->debug;
 
-        my $uri         = '/' . $c->request->path;
+        my $uri         = $c->request->uri->path_query;
         my $algorithm   = $res{algorithm} || 'MD5';
         my $nonce_count = '0x' . $res{nc};
 
@@ -600,7 +603,7 @@ C<password> methods return a hashed or salted version of the password.
 Updated to current name space and currently maintained
 by: Tomas Doran C<bobtfish@bobtfish.net>.
 
-Original module by: 
+Original module by:
 
 =over
 
@@ -612,6 +615,16 @@ Original module by:
 
 =back
 
+=head1 CONTRIBUTORS
+
+Patches contributed by:
+
+=over
+
+=item Peter Corlett
+
+=back
+
 =head1 SEE ALSO
 
 RFC 2617 (or its successors), L<Catalyst::Plugin::Cache>, L<Catalyst::Plugin::Authentication>
